# File generated from our OpenAPI spec by Stainless.

from __future__ import annotations

from typing import List
from typing_extensions import TypedDict

__all__ = ["ExternalAccountCompleteVerificationParams"]


class ExternalAccountCompleteVerificationParams(TypedDict, total=False):
    amounts: List[int]
